import os
from dotenv import load_dotenv

def load_env(env: str = None):
    """
    根据传入的环境名加载对应的 .env 文件，默认加载 .env
    """
    if env is None:
        env = os.getenv("ENV", "prod")  # 默认prod

    dotenv_path = os.path.join(os.path.dirname(os.path.dirname(__file__)), f".env.{env}")
    load_dotenv(dotenv_path)
    print(f"加载环境配置文件: {dotenv_path}")

def get_env(key: str, default: str = "") -> str:
    """获取环境变量"""
    return os.getenv(key, default)

def get_int_env(key: str, default: int = 0) -> int:
    """获取整数类型环境变量"""
    try:
        return int(os.getenv(key, default))
    except (TypeError, ValueError):
        return default


# 自动加载环境变量
load_env()

